#
# spec file for package python-pymacaroons-pynacl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         github_name pymacaroons
Name:           python-pymacaroons-pynacl
Version:        0.9.3
Release:        6.2
Summary:        Macaroon library for Python
License:        MIT
URL:            https://github.com/matrix-org/pymacaroons
Source:         https://github.com/matrix-org/%{github_name}/archive/v%{version}/pymacaroons-%{version}.tar.gz
# https://github.com/ecordell/pymacaroons/pull/54/
Patch0:         python-pymacaroons-pynacl-remove-nose.patch
BuildRequires:  %{python_module PyNaCl}
BuildRequires:  %{python_module cffi}
BuildRequires:  %{python_module libnacl}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyNaCl
Requires:       python-cffi
Requires:       python-six
Conflicts:      python-pymacaroons
BuildArch:      noarch
%python_subpackages

%description
Macaroons, like cookies, are a form of bearer credential.
Unlike opaque tokens, macaroons embed caveats that define
specific authorization requirements for the target service,
the service that issued the root macaroon and which is
capable of verifying the integrity of macaroons it recieves.

Macaroons allow for delegation and attenuation of authorization.
They are simple and fast to verify, and decouple authorization policy
from the enforcement of that policy.

This is a Python implementation of Macaroons.

%prep
%autosetup -p1 -n %{github_name}-%{version}
# requires too old hypothesis
rm -f tests/property_tests/macaroon_property_tests.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -k 'not test_inspect'

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/pymacaroons
%{python_sitelib}/pymacaroons_pynacl-%{version}.dist-info

%changelog
* Mon Mar  4 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject and autosetup macros.
- No more greedy globs in %%files.
* Thu Apr  7 2022 pgajdos@suse.com
- do not require python-mock for build
- modified patches
  %% python-pymacaroons-pynacl-remove-nose.patch (refreshed)
* Mon Jun 29 2020 pgajdos@suse.com
- nose -> pytest
- added patches
  https://github.com/ecordell/pymacaroons/pull/54/
  + python-pymacaroons-pynacl-remove-nose.patch
* Tue Feb 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Conflict with pymacaroon
* Fri Dec  7 2018 Tomáš Chvátal <tchvatal@suse.com>
- Use correct fdupes call
- Run tests
* Sun Jun 18 2017 okurz@suse.com
- Convert to singlespec
* Mon Feb 27 2017 okurz@suse.com
- Initial submission
